
# Slot: created_by


agent that created the element

URI: [linkml:created_by](https://w3id.org/linkml/created_by)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | pav:createdBy |

